==> qgis_2.0.1.orig.tar.bz2: qgis-2.0.1/tests/src/core/qgscompositionchecker.h <==
/***************************************************************************
     qgscompositionchecker.h - check rendering of Qgscomposition against an expected image
                     --------------------------------------
               Date                 : 5 Juli 2012
               Copyright            : (C) 2012 by Marco Hugentobler
               email                : marco@sourcepole.ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSCOMPOSITIONCHECKER_H
#define QGSCOMPOSITIONCHECKER_H

#include <QString>
class QgsComposition;
class QImage;

/**Renders a composition to an image and compares with an expected output*/
class QgsCompositionChecker
{
  public:
    QgsCompositionChecker( const QString& testName, QgsComposition* composition, const QString& expectedImageFile );
    ~QgsCompositionChecker();

    bool testComposition( int page = 0 );

  private:
    QgsCompositionChecker(); //forbidden
    bool compareImages( const QImage& imgExpected, const QImage& imgRendered, const QString& differenceImagePath = QString() ) const;

    QString mTestName;
    QgsComposition* mComposition;
    QString mExpectedImageFile;
};

#endif // QGSCOMPOSITIONCHECKER_H

==> qgis_2.4.0.orig.tar.bz2: qgis-2.4.0/tests/src/core/qgscompositionchecker.h <==
/***************************************************************************
     qgscompositionchecker.h - check rendering of Qgscomposition against an expected image
                     --------------------------------------
               Date                 : 5 Juli 2012
               Copyright            : (C) 2012 by Marco Hugentobler
               email                : marco@sourcepole.ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSCOMPOSITIONCHECKER_H
#define QGSCOMPOSITIONCHECKER_H

#include "qgsrenderchecker.h"
#include <QString>

class QgsComposition;
class QImage;

/**Renders a composition to an image and compares with an expected output*/
class QgsCompositionChecker : public QgsRenderChecker
{
  public:
    QgsCompositionChecker( const QString& testName, QgsComposition* composition );
    ~QgsCompositionChecker();

    bool testComposition( QString &report, int page = 0, int pixelDiff = 0 );

  private:
    QgsCompositionChecker(); //forbidden

    QString mTestName;
    QgsComposition* mComposition;


};

#endif // QGSCOMPOSITIONCHECKER_H
